@@ -20,7 +20,7 @@ shutil.copytree("python_embed-32", "dist/python_embed")
 if os.path.exists("dist/ev3sim/user_config.yaml"):
     os.remove("dist/ev3sim/user_config.yaml")
 
-process = Popen("makensis config.nsi")
+process = Popen(["makensis", "config.nsi"])
 process.wait()
 shutil.move("installer.exe", "installer-32bit.exe")
 
@@ -35,6 +35,6 @@ shutil.copytree("python_embed-64", "dist/python_embed")
 if os.path.exists("dist/ev3sim/user_config.yaml"):
     os.remove("dist/ev3sim/user_config.yaml")
 
-process = Popen("makensis config.nsi")
+process = Popen(["makensis", "config.nsi"])
 process.wait()
 shutil.move("installer.exe", "installer-64bit.exe")
