@@ -7,6 +7,7 @@ CLOSE_CLIENT = 4
 SEND_DATA = 5
 MESSAGE_PRINT = 6
 BOT_COMMAND = 7
+MESSAGE_INPUT_REQUESTED = 8
 
 # Simulation writes
 SIM_DATA = 0
@@ -17,6 +18,9 @@ CLIENT_CLOSED = 4
 RECV_DATA = 5
 SEND_SUCCESS = 6
 SERVER_SUCCESS = 7
+SIM_INPUT = 8
 
 # Command information
 EV3SIM_BOT_COMMAND = "EV3SIM_BOT_COMMAND"
+EV3SIM_PRINT = "EV3SIM_PRINT"
+EV3SIM_MESSAGE_POSTED = "EV3SIM_MESSAGE_POSTED"
