@@ -4,7 +4,7 @@ from ev3sim.visual.utils import screenspace_to_worldspace
 from ev3sim.simulation.interactor import IInteractor
 from ev3sim.simulation.loader import ScriptLoader
 from ev3sim.simulation.world import World
-from ev3sim.objects.base import DYNAMIC_CATEGORY
+from ev3sim.objects.base import STATIC_CATEGORY
 
 
 class PauseInteractor(IInteractor):
@@ -18,7 +18,7 @@ class PauseInteractor(IInteractor):
         if event.type == pygame.MOUSEBUTTONDOWN and event.button == 1:
             m_pos = screenspace_to_worldspace(event.pos)
             shapes = World.instance.space.point_query(
-                m_pos, 0.0, pymunk.ShapeFilter(mask=pymunk.ShapeFilter.ALL_MASKS ^ DYNAMIC_CATEGORY)
+                [float(v) for v in m_pos], 0.0, pymunk.ShapeFilter(mask=STATIC_CATEGORY)
             )
             if shapes:
                 max_z = max(pq.shape.obj.clickZ for pq in shapes)
@@ -30,7 +30,7 @@ class PauseInteractor(IInteractor):
         if event.type == pygame.MOUSEBUTTONUP and event.button == 1:
             m_pos = screenspace_to_worldspace(event.pos)
             shapes = World.instance.space.point_query(
-                m_pos, 0.0, pymunk.ShapeFilter(mask=pymunk.ShapeFilter.ALL_MASKS ^ DYNAMIC_CATEGORY)
+                [float(v) for v in m_pos], 0.0, pymunk.ShapeFilter(mask=STATIC_CATEGORY)
             )
             if shapes:
                 max_z = max(pq.shape.obj.clickZ for pq in shapes)
@@ -45,10 +45,8 @@ class PauseInteractor(IInteractor):
 
     def tick(self, tick):
         if self._pressed:
-            ScriptLoader.instance.object_map["controlsPause"].visual.image_path = "assets/ui/controls_pause_pressed.png"
+            ScriptLoader.instance.object_map["controlsPause"].visual.image_path = "ui/controls_pause_pressed.png"
         elif World.instance.paused:
-            ScriptLoader.instance.object_map["controlsPause"].visual.image_path = "assets/ui/controls_pause_hold.png"
+            ScriptLoader.instance.object_map["controlsPause"].visual.image_path = "ui/controls_pause_hold.png"
         else:
-            ScriptLoader.instance.object_map[
-                "controlsPause"
-            ].visual.image_path = "assets/ui/controls_pause_released.png"
+            ScriptLoader.instance.object_map["controlsPause"].visual.image_path = "ui/controls_pause_released.png"
